#ifndef _IMQMGR_HPP_
#define _IMQMGR_HPP_

//  Library:       MQSeries
//  Component:     IMQI (MQSeries C++ MQI)
//  Part:          IMQMGR.HPP
//
//  Description:   "ImqQueueManager" class declaration
//
//  Statement:     Licensed Materials - Property of IBM
//
//                 84H2000, 5765-B73
//                 84H2001, 5639-B42
//                 84H2002, 5765-B74
//                 84H2003, 5765-B75
//                 84H2004, 5639-B43
//                 (C) Copyright IBM Corp. 1994, 1997
//
//                 U.S. Government Users Restricted Rights -
//                 use, duplication or disclosure restricted by
//                 GSA ADP Schedule Contract with IBM Corp.

#include <imqobj.hpp> // ImqObject

extern "C" {
typedef struct tagMQBO1 {
  MQCHAR4 StrucId ;
  MQLONG Version ;
  MQLONG Options ;
} MQBO1 ;
typedef MQBO1 MQPOINTER PMQBO1 ;
}

extern "C" {
typedef struct tagMQCNO1 {
  MQCHAR4 StrucId ;
  MQLONG Version ;
  MQLONG Options ;
} MQCNO1 ;
typedef MQCNO1 MQPOINTER PMQCNO1 ;
}

#define IMQ_EXPL_DISC_BACKOUT 0L
#define IMQ_EXPL_DISC_COMMIT  1L
#define IMQ_IMPL_CONN         2L
#define IMQ_IMPL_DISC_BACKOUT 0L
#define IMQ_IMPL_DISC_COMMIT  4L

class ImqQueueManager : public ImqObject {
  ImqQueueManager * opmgrNext ;
  ImqQueueManager * opmgrPrevious ;
  ImqObject * opobjectFirst ;
  unsigned int obConnected : 1 ;
  unsigned int obOriginalConnection : 1 ;
  unsigned int obImplicitDisconnect : 1 ;
  unsigned int obPadding1 : 13 ;
  unsigned int obPadding2 : 16 ;
  // New methods:
  void init ( );
  static ImqBoolean lock ( );
  static ImqBoolean unlock ( );
protected :
  friend class ImqObject ;
  MQHCONN ohconn ;
  MQBO1 omqbo ;
  MQCNO1 omqcno ;
  // New methods:
  void setFirstManagedObject ( const ImqObject * pobject = 0 )
    { opobjectFirst = (ImqObject *)pobject ; }
public :
  // Overloaded "ImqObject" methods:
  virtual ImqBoolean description ( ImqString & );
  virtual ImqBoolean name ( ImqString & );
  // Directed "ImqObject" methods:
  ImqString description ( ) { return ImqObject::description( ); }
  ImqString name ( ) { return ImqObject::name( ); }
  // New methods:
  ImqQueueManager ( );
  ImqQueueManager ( const char * );
  ImqQueueManager ( const ImqQueueManager & );
  virtual ~ ImqQueueManager ( );
  void operator = ( const ImqQueueManager & );
  ImqBoolean authorityEvent ( MQLONG & );
  MQLONG authorityEvent ( );
  ImqBoolean backout ( );
  ImqBoolean begin ( );
  MQLONG beginOptions ( ) const { return omqbo.Options ; }
  static MQLONG behavior ( );
  static MQLONG behaviour ( ) { return ImqQueueManager::behavior( ); }
  ImqBoolean characterSet ( MQLONG & );
  MQLONG characterSet ( );
#ifdef MQCA_CLUSTER_WORKLOAD_DATA
  ImqBoolean clusterWorkLoadData ( ImqString & );
  ImqString clusterWorkLoadData ( );
#endif
#ifdef MQCA_CLUSTER_WORKLOAD_EXIT
  ImqBoolean clusterWorkLoadExit ( ImqString & );
  ImqString clusterWorkLoadExit ( );
#endif
#ifdef MQIA_CLUSTER_WORKLOAD_LENGTH
  ImqBoolean clusterWorkLoadLength ( MQLONG & );
  MQLONG clusterWorkLoadLength ( );
#endif
  ImqBoolean commandInputQueueName ( ImqString & );
  ImqString commandInputQueueName ( );
  ImqBoolean commandLevel ( MQLONG & );
  MQLONG commandLevel ( );
  ImqBoolean commit ( );
  ImqBoolean connect ( );
  MQLONG connectOptions ( ) const { return omqcno.Options ; }
  ImqBoolean connectionStatus ( ) const { return (ImqBoolean)obConnected ; }
  ImqString deadLetterQueueName ( );
  ImqBoolean deadLetterQueueName ( ImqString & );
  ImqBoolean defaultTransmissionQueueName ( ImqString & );
  ImqString defaultTransmissionQueueName ( );
  ImqBoolean disconnect ( );
  ImqBoolean distributionLists ( MQLONG & );
  MQLONG distributionLists ( );
  ImqObject * firstManagedObject ( ) const { return opobjectFirst ; }
  ImqBoolean inhibitEvent ( MQLONG & );
  MQLONG inhibitEvent ( );
  ImqBoolean localEvent ( MQLONG & );
  MQLONG localEvent ( );
  ImqBoolean maximumHandles ( MQLONG & );
  MQLONG maximumHandles ( );
  ImqBoolean maximumMessageLength ( MQLONG & );
  MQLONG maximumMessageLength ( );
  ImqBoolean maximumPriority ( MQLONG & );
  MQLONG maximumPriority ( );
#if defined( MQIA_MAX_UNCOMMITTED_MSGS )
  ImqBoolean maximumUncommittedMessages ( MQLONG & );
  MQLONG maximumUncommittedMessages ( );
#endif
  ImqBoolean performanceEvent ( MQLONG & );
  MQLONG performanceEvent ( );
  ImqBoolean platform ( MQLONG & );
  MQLONG platform ( );
  ImqBoolean remoteEvent ( MQLONG & );
  MQLONG remoteEvent ( );
#ifdef MQCA_REPOSITORY_NAME
  ImqBoolean repositoryName ( ImqString & );
  ImqString repositoryName ( );
#endif
#ifdef MQCA_REPOSITORY_NAMELIST
  ImqBoolean repositoryNamelistName ( ImqString & );
  ImqString repositoryNamelistName ( );
#endif
#if defined( MQBO_NONE )
  void setBeginOptions ( const MQLONG l = MQBO_NONE ) { omqbo.Options = l ; }
#endif
  static void setBehavior ( const MQLONG = 0 );
  static void setBehaviour ( const MQLONG l = 0 )
    { ImqQueueManager::setBehavior( l ); }
#if defined( MQCNO_NONE )
  void setConnectOptions ( const MQLONG l = MQCNO_NONE )
    { omqcno.Options = l ; }
#endif
  ImqBoolean startStopEvent ( MQLONG & );
  MQLONG startStopEvent ( );
  ImqBoolean syncPointAvailability ( MQLONG & );
  MQLONG syncPointAvailability ( );
  ImqBoolean triggerInterval ( MQLONG & );
  MQLONG triggerInterval ( );
  ImqBoolean channelAutoDefinition ( MQLONG & );
  MQLONG channelAutoDefinition ( );
  ImqBoolean channelAutoDefinitionEvent ( MQLONG & );
  MQLONG channelAutoDefinitionEvent ( );
  ImqBoolean channelAutoDefinitionExit ( ImqString & );
  ImqString channelAutoDefinitionExit ( );
} ;

#endif
